@@ -14,10 +14,12 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-#include <qobjectlist.h>
-#include <qobjectdict.h>
+#include <qobject.h>
+#include <q3objectdict.h>
+//Added by qt3to4:
+#include <QResizeEvent>
 
 #include "InfoShellWidget.h"
 
@@ -34,10 +36,9 @@ InfoShellWidget::~InfoShellWidget()
 
 void InfoShellWidget::resizeEvent( QResizeEvent* )
 {
-    if ( children() ) {
-        QObjectListIt i( *children() );
-        for ( ; i.current(); ++i ) {
-            ((QWidget*)i.current())->resize( size() );
+    if ( !children().isEmpty() ) {
+       for (int i = 0; i < children().size(); ++i) {
+		((QWidget*)children().at(i))->resize(size());
         }
     }
 }
