@@ -1,6 +1,25 @@
-// (c) 2000 Peter Putzer
+/*
+   Copyright 2000 Peter Putzer <putzer@kde.org>
 
-#include <qlineedit.h>
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
+#include <QLineEdit>
+//Added by qt3to4:
+#include <QKeyEvent>
+#include <QEvent>
 
 #include <kdebug.h>
 
@@ -8,7 +27,7 @@
 #include "SpinBox.h"
 
 KSVSpinBox::KSVSpinBox (QWidget* parent, const char* name)
-  : QSpinBox (0, 99, 1, parent, name),
+  : KIntSpinBox (0, 99, 1, parent, name),
     KCompletionBase (),
     mClearedSelection (false)
 {
@@ -64,14 +83,15 @@ void KSVSpinBox::handleMatch (const QString& match)
 
 bool KSVSpinBox::eventFilter (QObject* o, QEvent* e)
 {
+  Q_UNUSED(o);
   if (e->type() == QEvent::KeyPress)
     {
       QKeyEvent* ke = static_cast<QKeyEvent*> (e);
       
       switch (ke->key())
         {
-        case Key_BackSpace:
-        case Key_Delete:
+        case Qt::Key_Backspace:
+        case Qt::Key_Delete:
           mClearedSelection = true;
           break;
 
