@@ -19,13 +19,13 @@
 #ifndef KSV_SPINBOX_H
 #define KSV_SPINBOX_H
 
-#include <QSpinBox>
 //Added by qt3to4:
 #include <QEvent>
 
 #include <kcompletion.h>
+#include <KNumInput>
 
-class KSVSpinBox : public QSpinBox, public KCompletionBase
+class KSVSpinBox : public KIntSpinBox, public KCompletionBase
 {
   Q_OBJECT
 
