@@ -1,6 +1,4 @@
 /***************************************************************************
-                          leveldb.h  -  description
-                             -------------------
     begin                : Sun Oct 3 1999
     copyright            : (C) 1999 by Red Hat Software
     email                : putzer@kde.org
