@@ -70,7 +70,7 @@ General::General(liloconf *l, QWidget *parent):QWidget(parent)
 	KHBox *modes=new KHBox(this);
 	linear=new QCheckBox(_("Use &linear mode"), modes);
 	connect(linear, SIGNAL(clicked()), SIGNAL(configChanged()));
-	linear->setWhatsThis( _("Check this box if you want to use the linear mode.<br>Linear mode tells the boot loader the location of kernels in linear addressing rather than sector/head/cylinder.<br>linear mode is required for some SCSI drives, and shouldn't hurt unless you're planning to create a boot disk to be used with a different computer.<br>See the lilo.conf man page for details."));
+	linear->setWhatsThis( _("Check this box if you want to use the linear mode.<br>Linear mode tells the boot loader the location of kernels in linear addressing rather than sector/head/cylinder.<br>Linear mode is required for some SCSI drives, and should not cause problems unless you are planning to create a boot disk to be used with a different computer.<br>See the lilo.conf man page for details."));
 	compact=new QCheckBox(_("Use &compact mode"), modes);
 	connect(compact, SIGNAL(clicked()), SIGNAL(configChanged()));
 	compact->setWhatsThis( _("Check this box if you want to use the compact mode.<br>The compact mode tries to merge read requests for adjacent sectors into a single read request. This reduces load time and keeps the boot map smaller, but will not work on all systems."));
@@ -94,7 +94,7 @@ General::General(liloconf *l, QWidget *parent):QWidget(parent)
 	password->setMaxLength(15);
 	password->setEchoMode(QLineEdit::Password);
 	connect(password, SIGNAL(textChanged(const QString &)), SIGNAL(configChanged()));
-	pw->setWhatsThis( _("Enter the password required for bootup (if any) here. If <i>restricted</i> above is checked, the password is required for additional parameters only.<br><b>WARNING:</b> The password is stored in clear text in /etc/lilo.conf. You'll want to make sure nobody untrusted can read this file. Also, you probably don't want to use your normal/root password here.<br>This sets a default for all Linux kernels you want to boot. If you need a per-kernel setting, go to the <i>Operating systems</i> tab and select <i>Details</i>."));
+	pw->setWhatsThis( _("Enter the password required for bootup (if any) here. If <i>restricted</i> is checked above, the password is only required for additional parameters.<br><b>WARNING:</b> The password is stored in clear text in /etc/lilo.conf. Make sure that nobody untrusted can read this file. Also, you probably do not want to use your normal/root password here.<br>This sets a default for all Linux kernels you want to boot. If you need a per-kernel setting, go to the <i>Operating systems</i> tab and select <i>Details</i>."));
 	layout->addWidget(pw);
 
 	KHBox *vgab=new KHBox(this);
